camelot.camelot.view.plugins

Package camelot :: Package camelot :: Package view :: Package plugins |
[hide private]
[frames] | no frames]

# Package plugins

source code

Plugins to include custom Camelot editors into QT Designer

Submodules | [hide private]
camelot.camelot.view.plugins.codeeditorplugin camelot.camelot.view.plugins.dateeditorplugin camelot.camelot.view.plugins.imageeditorplugin camelot.camelot.view.plugins.manytooneeditorplugin camelot.camelot.view.plugins.onetomanyeditorplugin camelot.camelot.view.plugins.richtexteditorplugin

Classes | [hide private]
| CamelotEditorPlugin